@@ -3,11 +3,19 @@ import contextlib
 from typing import Union
 
 from streamlit.server.server import Server
+from tornado.platform.asyncio import BaseAsyncIOLoop
 
 
 def get_server_event_loop() -> asyncio.AbstractEventLoop:
     current_server = Server.get_current()
-    return current_server._ioloop.asyncio_loop
+    ioloop = current_server._ioloop
+
+    # `ioloop` is expected to be of type `BaseAsyncIOLoop`,
+    # which has the `asyncio_loop` attribute.
+    if not isinstance(ioloop, BaseAsyncIOLoop):
+        raise Exception("Unexpectedly failed to access the asyncio event loop.")
+
+    return ioloop.asyncio_loop
 
 
 @contextlib.contextmanager
